Learn R Programming

covid19mobility (version 0.1.1)

get_info_covid19mobility: Get information about the datasets provided by covid19mobility

Description

Returns information about the datasets in this package for covid19R harvesting

Usage

get_info_covid19mobility()

Arguments

Value

a tibble of information about the datasets in this package

Examples

Run this code
# NOT RUN {
# get the dataset info from this package
get_info_covid19mobility()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab