powered by
Returns information about the datasets in this package for covid19R harvesting
get_info_covid19mobility()
a tibble of information about the datasets in this package
# NOT RUN { # get the dataset info from this package get_info_covid19mobility() # } # NOT RUN { # }
Run the code above in your browser using DataLab